@@ -1,6 +1,8 @@
 import pandas as pd
+import os
 from xmindparser import xmind_to_dict
 
+
 class ConvertXmindToExcel:
     def __init__(self):
         self.markdown_dict = dict()
@@ -35,13 +37,66 @@ class ConvertXmindToExcel:
         self.index = 0
         self.ignore_layer_number = 0
 
-    def convert(self, markdown_path, excel_path, ignore_layer_number='0'):
-        self.ignore_layer_number = int(ignore_layer_number)
-        self.parseXmindToDict(markdown_path)
-        df = pd.DataFrame(self.markdown_dict)
-        writer = pd.ExcelWriter(excel_path, engine='xlsxwriter')
-        df.to_excel(writer, sheet_name='case_data', index=False)
-        writer.save()
+    def convert(self, xmind_path, excel_path, ignore_layer_number='0'):
+        if os.path.isfile(xmind_path):
+            # 如果传递单个xmind文件，则直接转换
+            self.convert_single_file(xmind_path, excel_path, ignore_layer_number)
+        if os.path.isdir(xmind_path):
+            # 如果传递xmind文件夹的路径，则遍历文件夹中的xmind文件进行转换，放到指定的目录下面
+            if not os.path.exists(excel_path):
+                os.makedirs(excel_path)
+            xmind_dir = os.walk(xmind_path)
+            for path, dir_list, file_list in xmind_dir:
+                for file_name in file_list:
+                    if not file_name.endswith('.xmind'):
+                        continue
+                    print(os.path.join(path, file_name))
+                    print(os.path.join(excel_path, file_name.replace('.xmind', '.xlsx')))
+                    self.convert_single_file(os.path.join(path, file_name),
+                                             os.path.join(excel_path, file_name.replace('.xmind', '.xlsx')),
+                                             ignore_layer_number)
+
+    # 将单个xmind转换为单个excel文件
+    def convert_single_file(self, xmind_path, excel_path, ignore_layer_number):
+        try:
+            self.ignore_layer_number = int(ignore_layer_number)
+            self.parseXmindToDict(xmind_path)
+            df = pd.DataFrame(self.markdown_dict)
+            writer = pd.ExcelWriter(excel_path, engine='xlsxwriter')
+            df.to_excel(writer, sheet_name='case_data', index=False)
+            writer.save()
+        finally:
+            self.markdown_dict = dict()
+            self.feature_layer = '特性层级'
+            self.case_title = '用例标题'
+            self.case_description = '用例描述'
+            self.case_pre_condition = '前置条件'
+            self.case_steps = '测试步骤'
+            self.result = '预期结果'
+            self.country_tag = '国家标签'
+            self.jira_no = 'jira编号'
+            self.case_level = '用例等级'
+            self.applicable_stage = '适用阶段'
+            self.case_type = '用例类型'
+            self.case_maintainer = '用例负责人'
+            self.case_keyword = '用例关键字'
+            self.case_remark = '备注'
+            self.markdown_dict[self.feature_layer] = []
+            self.markdown_dict[self.case_title] = []
+            self.markdown_dict[self.case_description] = []
+            self.markdown_dict[self.case_pre_condition] = []
+            self.markdown_dict[self.case_steps] = []
+            self.markdown_dict[self.result] = []
+            self.markdown_dict[self.country_tag] = []
+            self.markdown_dict[self.jira_no] = []
+            self.markdown_dict[self.case_level] = []
+            self.markdown_dict[self.applicable_stage] = []
+            self.markdown_dict[self.case_type] = []
+            self.markdown_dict[self.case_maintainer] = []
+            self.markdown_dict[self.case_keyword] = []
+            self.markdown_dict[self.case_remark] = []
+            self.index = 0
+            self.ignore_layer_number = 0
 
     def parseXmindToDict(self, xmind_file_path):
         content_dict = xmind_to_dict(xmind_file_path)
@@ -157,7 +212,3 @@ class ConvertXmindToExcel:
         elif content.startswith(self.case_remark + ':') or content.startswith(self.case_remark + '：'):
             return self.case_remark, content.lstrip().replace(self.case_remark + ':', '').replace(
                 self.case_remark + '：', '')
-
-
-
-
